summaryrefslogtreecommitdiffstats
path: root/ui/gfx/screen.h
diff options
context:
space:
mode:
Diffstat (limited to 'ui/gfx/screen.h')
-rw-r--r--ui/gfx/screen.h24
1 files changed, 13 insertions, 11 deletions
diff --git a/ui/gfx/screen.h b/ui/gfx/screen.h
index 12ecb6c..69a6726 100644
--- a/ui/gfx/screen.h
+++ b/ui/gfx/screen.h
@@ -6,6 +6,7 @@
#define UI_GFX_SCREEN_H_
#pragma once
+#include "base/basictypes.h"
#include "ui/base/ui_export.h"
#include "ui/gfx/display.h"
#include "ui/gfx/native_widget_types.h"
@@ -15,12 +16,10 @@ namespace gfx {
class Rect;
class ScreenImpl;
// A utility class for getting various info about screen size, monitors,
// cursor position, etc.
class UI_EXPORT Screen {
public:
- virtual ~Screen() {}
-
#if defined(USE_AURA)
// Sets the instance to use. This takes owernship of |screen|, deleting the
// old instance. This is used on aura to avoid circular dependencies between
@@ -37,24 +36,27 @@ class UI_EXPORT Screen {
// Returns the window under the cursor.
static gfx::NativeWindow GetWindowAtCursorScreenPoint();
// Returns the number of monitors.
// Mirrored displays are excluded; this method is intended to return the
// number of distinct, usable displays.
- static int GetNumMonitors();
+ static int GetNumDisplays();
// Returns the display nearest the specified window.
- static gfx::Display GetMonitorNearestWindow(gfx::NativeView view);
+ static gfx::Display GetDisplayNearestWindow(gfx::NativeView view);
// Returns the the display nearest the specified point.
- static gfx::Display GetMonitorNearestPoint(const gfx::Point& point);
+ static gfx::Display GetDisplayNearestPoint(const gfx::Point& point);
- // Returns the bounds of the work area of the primary monitor.
- static gfx::Display GetPrimaryMonitor();
+ // Returns the bounds of the work area of the primary display.
+ static gfx::Display GetPrimaryDisplay();
// Returns the display that most closely intersects the provided bounds.
- static gfx::Display GetMonitorMatching(const gfx::Rect& match_rect);
+ static gfx::Display GetDisplayMatching(const gfx::Rect& match_rect);
+
+ private:
+ DISALLOW_IMPLICIT_CONSTRUCTORS(Screen);
};
} // namespace gfx
-#endif // VIEWS_SCREEN_H_
+#endif // UI_GFX_SCREEN_H_
@@ -15,12 +16,10 @@ namespace gfx {
class Rect;
class ScreenImpl;
-// A utility class for getting various info about screen size, monitors,
+// A utility class for getting various info about screen size, displays,
// cursor position, etc.
class UI_EXPORT Screen {
@@ -37,24 +36,27 @@ class UI_EXPORT Screen {
// Returns the window under the cursor.
static gfx::NativeWindow GetWindowAtCursorScreenPoint();
- // Returns the number of monitors.
+ // Returns the number of displays.
// Mirrored displays are excluded; this method is intended to return the
// number of distinct, usable displays.